# krakenpy

krakenpy is a python integration for kraken API. This package is using `krakenex` underneath, because `krakenex` only provides two methods `query_private` and `query_public` and it's really hard to guess the request params. Therefore, I have introduced Python `Typing` and `dataclasses` to readability.

## Authors

- [Sheikh Haris Zahid](https://github.com/sheikhharis50)
